@@ -115,6 +115,9 @@ class IOLoop(object):
     WRITE = _EPOLLOUT
     ERROR = _EPOLLERR | _EPOLLHUP
 
+    # Global lock for creating global IOLoop instance
+    _instance_lock = threading.Lock()
+
     def __init__(self, impl=None):
         self._impl = impl or _poll()
         if hasattr(self._impl, 'fileno'):
@@ -153,7 +156,10 @@ class IOLoop(object):
                     self.io_loop = io_loop or IOLoop.instance()
         """
         if not hasattr(IOLoop, "_instance"):
-            IOLoop._instance = IOLoop()
+            with IOLoop._instance_lock:
+                if not hasattr(IOLoop, "_instance"):
+                    # New instance after double check
+                    IOLoop._instance = IOLoop()
         return IOLoop._instance
 
     @staticmethod
@@ -446,6 +452,14 @@ class IOLoop(object):
         in sys.exc_info.
         """
         logging.error("Exception in callback %r", callback, exc_info=True)
+    
+    def time(self):
+        """This method will be added in tornado 3.0
+        
+        When 3.0 is closer to done, we will do a real upstream sync,
+        but this seems to be enough for now.
+        """
+        return time.time()
 
 
 class _Timeout(object):
